@@ -8,8 +8,11 @@
 from mesh.boost.disruptor import Disruptor, BatchConsumer, Consumer, RingBuffer, RingBufferLagStats
 from mesh.boost.mooter import Mooter
 from mesh.boost.runhook import Runtime
+from mesh.boost.scheduler import PythonScheduler
 
-__all__ = ("Disruptor", "BatchConsumer", "Consumer", "RingBuffer", "RingBufferLagStats", "Mooter", "Runtime")
+__all__ = (
+    "Disruptor", "BatchConsumer", "Consumer", "RingBuffer", "RingBufferLagStats", "Mooter", "Runtime",
+    "PythonScheduler")
 
 
 def init():
