@@ -22,7 +22,6 @@ from mesh.mpc.invoker import Execution
 
 @spi("grpc")
 class GrpcConsumer(Consumer):
-    PATH = "/mesh-rpc/v1"
 
     def __init__(self):
         self.channel = GrpcChannels()
@@ -73,15 +72,6 @@ class GrpcConsumer(Consumer):
                                     f'Invoke {execution.schema().urn} {e.code()} {e.details()}')
             raise e
 
-    def unary(self, urn: str, channel: grpc.Channel, inbound: bytes, timeout: Any) -> grpc.Future:
-        conn: grpc.UnaryUnaryMultiCallable = channel.unary_unary(GrpcConsumer.PATH, self.serializer, self.deserializer)
-        return conn(inbound, timeout, [], None, True)
-
-    def stream(self, channel: grpc.Channel, inbound: bytes, timeout: Any) -> grpc.Future:
-        conn: grpc.StreamStreamMultiCallable = channel.stream_stream(GrpcConsumer.PATH, self.serializer,
-                                                                     self.deserializer)
-        return conn(inbound, timeout, None, None, True)
-
     @staticmethod
     def resolve(address: str):
         hosts = tool.split(address, ":")
