@@ -5,6 +5,7 @@
 #
 from typing import Any
 
+import mesh.log as log
 from mesh.macro import spi
 from mesh.mpc import Provider
 
@@ -13,7 +14,7 @@ from mesh.mpc import Provider
 class HTTPProvider(Provider):
 
     def start(self, address: str, tc: Any):
-        pass
+        log.info(f"Listening and serving HTTP 1.x on {address}")
 
     def close(self):
-        pass
+        log.info(f"Graceful stop HTTP 1.x serving")
