@@ -4,7 +4,6 @@
 #
 #
 
-from __future__ import annotations
 
 from mesh.macro.index import index
 
@@ -28,9 +27,9 @@ class Cause:
         return b''
 
     @staticmethod
-    def of(e: BaseException) -> Cause:
+    def of(e: BaseException) -> "Cause":
         return Cause()
 
     @staticmethod
-    def of_cause(code: str, message: str, cause: Cause) -> BaseException:
+    def of_cause(code: str, message: str, cause: "Cause") -> BaseException:
         raise BaseException("")
