@@ -7,7 +7,7 @@
 
 import inspect
 from abc import ABC, abstractmethod
-from typing import Any, Type, Callable
+from typing import Any, Type
 
 from mesh.macro.ark import ark, T
 from mesh.macro.loader import ServiceLoader
@@ -25,7 +25,7 @@ class MethodProxy(ABC):
 
 class MPI:
 
-    def __init__(self, fn: Callable[..., T] = None, name='', version='', proto='grpc', codec='json',
+    def __init__(self, fn: str = None, name='', version='', proto='grpc', codec='json',
                  asyncable=True, timeout=10000, retries=3, node='', inst='', zone='', cluster='', cell='', group='',
                  address='', encrypt=False):
         """
@@ -105,7 +105,7 @@ class MPI:
         return MPI()
 
 
-def mpi(fn: Callable[..., T] = None, *, name='', version='', proto='grpc', codec='json', asyncable=True,
+def mpi(fn: str = None, *, name='', version='', proto='grpc', codec='json', asyncable=True,
         timeout=10000, retries=3, node='', inst='', zone='', cluster='', cell='', group='', address='',
         encrypt=False) -> T:
     return MPI(fn, name, version, proto, codec, asyncable, timeout, retries, node, inst, zone, cluster, cell, group,
