@@ -59,6 +59,9 @@ class Proxy(Generic[T]):
     def __target__(self):
         return object.__getattribute__(self, "_target_")
 
+    def __handler__(self):
+        return object.__getattribute__(self, "_handler_")
+
     def __nonzero__(self):
         return bool(self.__target__())
 
@@ -91,7 +94,7 @@ class Proxy(Generic[T]):
     def __call__(self, *args, **kwargs):
         return self
 
-    def __new__(cls, kind: type, handler: InvocationHandler, *args, **kwargs):
+    def __new__(cls, kinds: List[Type], handler: InvocationHandler, *args, **kwargs):
         """
         Creates an proxy instance referencing `interface`. (interface, *args, **kwargs) are
         passed to this class' __init__, so deriving classes can define an
@@ -99,7 +102,7 @@ class Proxy(Generic[T]):
         note: _proxy_class_cache_ is unique per deriving class (each deriving
         class must hold its own cache)
         """
-        proxy_class = cls.create_proxy_class(kind, handler)
+        proxy_class = cls.create_proxy_class(kinds)
         instance = object.__new__(proxy_class)
         instance.__init__(instance, handler)
         return instance
@@ -122,32 +125,35 @@ class Proxy(Generic[T]):
     ]
 
     @classmethod
-    def create_proxy_class(cls, kind: type, handler: InvocationHandler) -> Type["Proxy"]:
+    def create_proxy_class(cls, kinds: List[Type]) -> Type["Proxy"]:
         """
         Creates a proxy for the given class
         """
-        qname = f"{str(kind)}{str(handler.__class__)}"
+        qname = ",".join(sorted(map(lambda x: str(x), kinds)))
         if hasattr(cls, '__proxy_classes__') and cls.__proxy_classes__.get(qname):
             return cls.__proxy_classes__.get(qname)
 
         if not hasattr(cls, '__proxy_classes__'):
             cls.__proxy_classes__ = {}
 
-        methods = Proxy.get_abstract_methods(kind)
         namespace = {}
-        for name in cls._special_names_:
-            if hasattr(kind, name) and not hasattr(cls, name) and not namespace.get(name):
-                namespace[name] = Proxy.make_special(name)
-        for name in methods:
-            namespace[name] = Proxy.make_delegate(methods[name], handler)
-        cls.__proxy_classes__[qname] = type("%s(%s)" % (cls.__name__, kind.__name__), (kind, cls), namespace)
+        for kind in kinds:
+            for name in cls._special_names_:
+                if hasattr(kind, name) and not hasattr(cls, name) and not namespace.get(name):
+                    namespace[name] = Proxy.make_special(name)
+
+        for kind in kinds:
+            for name, method in Proxy.get_abstract_methods(kind).items():
+                namespace[name] = Proxy.make_delegate(method)
+
+        cls.__proxy_classes__[qname] = type("%s(%s)" % (cls.__name__, qname), (*kinds, cls), namespace)
         return cls.__proxy_classes__[qname]
 
     @staticmethod
     def new_proxy(kind: Type[T], handler: InvocationHandler) -> T:
-        interface = kind
+        interface = [kind]
         if hasattr(kind, "__args__"):
-            interface = kind.__args__[0]
+            interface = kind.__args__
 
         return Proxy(interface, handler)
 
@@ -183,8 +189,8 @@ class Proxy(Generic[T]):
         return invoke
 
     @staticmethod
-    def make_delegate(method, handler: InvocationHandler):
+    def make_delegate(method):
         def invoke(self, *args, **kwargs):
-            return handler.invoke(self, method, *args, **kwargs)
+            return self.__handler__().invoke(self, method, *args, **kwargs)
 
         return invoke
