@@ -4,8 +4,6 @@
 #
 #
 
-from __future__ import annotations
-
 from typing import Type, Any, Generic
 
 from mesh.macro.ark import ark, T
@@ -13,7 +11,7 @@ from mesh.macro.ark import ark, T
 
 class SPI(Generic[T]):
 
-    def __init__(self, fn: T | str = None, name='', pattern='', priority=0, prototype=False):
+    def __init__(self, fn: T = None, name='', pattern='', priority=0, prototype=False):
         """
         Metadata annotation for Serial Peripheral Interface. Can be used with {@link ServiceLoader#load(Class)}
         or dependency injection at compile time and runtime time.
@@ -41,11 +39,11 @@ class SPI(Generic[T]):
         return self.kind
 
     @staticmethod
-    def get_macro(kind: Type[Any]) -> SPI:
+    def get_macro(kind: Type[Any]) -> "SPI":
         if hasattr(kind, '__spi__'):
             return kind.__spi__
         return SPI()
 
 
-def spi(fn: T | str = None, *, name='', pattern='', priority=0, prototype=False):
+def spi(fn: T = None, *, name='', pattern='', priority=0, prototype=False):
     return SPI(fn, name, pattern, priority, prototype)
