@@ -8,6 +8,7 @@ import mesh.mpc.consumer_filter
 import mesh.mpc.provider_filter
 import mesh.mpc.robust_filter
 from mesh.context import Mesh
+from mesh.context import MeshContext
 from mesh.mpc.compiler import Compiler
 from mesh.mpc.consumer import Consumer
 from mesh.mpc.eden import Eden
@@ -21,6 +22,7 @@ from mesh.mpc.schema import Schema
 from mesh.mpc.service_classloader import ServiceClassLoader
 from mesh.mpc.service_proxy import ServiceProxy
 from mesh.mpc.stream import MeshRoutable
+from mesh.mpc.transporter import Transporter, PROVIDER, CONSUMER
 from mesh.mpc.urn import MESH_DOMAIN, URN, URNFlag
 
 __all__ = (
@@ -42,6 +44,10 @@ __all__ = (
     "Compiler",
     "MESH_DOMAIN",
     "MeshRoutable",
+    "Transporter",
+    "PROVIDER",
+    "CONSUMER",
+    "MeshContext",
 )
 
 
