@@ -103,7 +103,7 @@ class URNFlag:
 
     @staticmethod
     def reduce(value: str, length: int):
-        buffer = []
+        buff = []
         for index, code in enumerate(value):
             if (index + length) % length != 0:
                 continue
@@ -112,12 +112,12 @@ class URNFlag:
                 if value[offset] != '0':
                     has_none_zero = False
                 if not has_none_zero:
-                    buffer.append(value[offset])
+                    buff.append(value[offset])
             if has_none_zero:
-                buffer.append('0')
-            buffer.append('.')
+                buff.append('0')
+            buff.append('.')
 
-        return ''.join(buffer[0:len(buffer) - 1])
+        return ''.join(buff[0:len(buff) - 1])
 
     def __init__(self):
         self.v = '00'  # #                 2      00
