@@ -3,17 +3,21 @@
 # TRUSTBE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 #
 #
-
+from mesh.macro import spi
 from mesh.prsim import RuntimeHook
 
 
+@spi("mesh")
 class MeshRuntimeHook(RuntimeHook):
 
     def start(self):
+        """"""
         pass
 
     def stop(self):
+        """"""
         pass
 
     def refresh(self):
+        """"""
         pass
